local config = require("OperatorJack.IllegalSummoning.config")

local function getMagicEffects()
    local list = {}
    for id, effect in pairs(tes3.dataHandler.nonDynamicData.magicEffects) do
        table.insert(list, effect.name:lower())
    end
    table.sort(list)
    return list
end

local function getNPCs()
    local temp = {}
    for obj in tes3.iterateObjects(tes3.objectType.npc) do
        temp[obj.name:lower()] = true
    end

    local list = {}
    for name in pairs(temp) do
        list[#list+1] = name
    end

    table.sort(list)
    return list
end

local function createGeneralCategory(template)
    local page = template:createSideBarPage{
        label = "Paramtres gnraux",
        description = "Passez le curseur sur un paramtre pour en savoir plus sur celui-ci."
    }

    local category = page:createCategory{
        label = "Paramtres gnraux"
    }

    -- Create option to capture debug mode.
    category:createSlider{
        label = "Valeur de la prime ",
        description = "Choisissez la prime minimale qui sera mise sur votre tte si vous tes surpris  invoquer illgalement en ville.",
        min = 0,
        max = 2500,
        step = 1,
        jump = 50,
        variable = mwse.mcm.createTableVariable{
            id = "bountyValue",
            table = config
        }
    }

    -- Create option to capture debug mode.
    category:createSlider{
        label = "Distance de dclenchement de crime pour les PNJs ",
        description = "Choisissez la distance  laquelle les gardes doivent tre pour attaquer un PNJ invoquant illgalement. Ce paramtre s'applique UNIQUEMENT aux PNJs.",
        min = 0,
        max = 5000,
        step = 1,
        jump = 100,
        variable = mwse.mcm.createTableVariable{
            id = "npcTriggerDistance",
            table = config
        }
    }

    return category
end

local function createNpcWhitelist(template)
    -- Whitelist Page
    template:createExclusionsPage{
        label = "Liste blanche des PNJs",
        description = "Les PNJs dans la liste blanche peuvent lancer des sorts d'invocation sans commettre de crime (sauf s'il s'agit d'un sort ou effet magique sur liste noire).",
        leftListLabel = "Liste blanche ",
        rightListLabel = "PNJs ",
        variable = mwse.mcm.createTableVariable{
            id = "npcWhitelist",
            table = config,
        },
        filters = {
            {callback = getNPCs},
        },
    }
end

local function createMagicEffectBlacklist(template)
    template:createExclusionsPage{
        label = "Liste noire des effets magiques",
        description = "Les effets magiques et sorts dans la liste noire dclencheront un crime, mme pour les PNJs sur liste blanche. Les effets magiques et sorts dans la liste blanche l'emportent sur ceux dans la liste noire.",
        leftListLabel = "Liste noire ",
        rightListLabel = "Effets magiques ",
        variable = mwse.mcm.createTableVariable{
            id = "effectBlacklist",
            table = config,
        },
        filters = {
            {callback = getMagicEffects},
        },
    }
end

local function createMagicEffectWhitelist(template)
    template:createExclusionsPage{
        label = "Liste blanche des effets magiques",
        description = "Les effets magiques et sorts dans la liste blanche ne dclencheront jamais de crime. Ce sont des sorts autoriss.",
        leftListLabel = "Liste blanche ",
        rightListLabel = "Effets magiques ",
        variable = mwse.mcm.createTableVariable{
            id = "effectWhitelist",
            table = config,
        },
        filters = {
            {callback = getMagicEffects},
        },
    }
end

-- Handle mod config menu.
local template = mwse.mcm.createTemplate("Invocation illgale")
template:saveOnClose("Illegal-Summoning", config)

createGeneralCategory(template)
createNpcWhitelist(template)
createMagicEffectBlacklist(template)
createMagicEffectWhitelist(template)

mwse.mcm.register(template)
